Method: Pthread::Pthread#value

Defined in:
lib/pthread/pthread.rb

#valueObject

Note:

If value if not yet calculated will block the execution

Note:

If pthread resulted in an exception it will be raised

Returns value of a pthread

Examples:

pthread.value

Returns:

  • (Object)

    value of a pthread



85
86
87
# File 'lib/pthread/pthread.rb', line 85

def value
  raw_value.is_a?(StandardError) ? raise(raw_value) : raw_value
end